==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/node_user.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="node_user.php" method="post">
<input type="hidden" name="data[user_id]" value="<?php echo $user['user_id'];?>" />

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "node_menu.inc.tpl.php";
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_action'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php
						if (isset($display) && $display == "view_user") {
						?>
						<a href="sn_profile.php?user_id=<?php echo $user['user_id'];?>" class="txt_sub_menu"><?php echo $lang['href_go_to_user'];?></a><br />
						<a href="node_user.php?edit_user=1&amp;user_id=<?php echo $user['user_id'];?>" class="txt_sub_menu"><?php echo $lang['href_edit_user'];?></a><br />
						<a href="node_user.php" class="txt_sub_menu"><?php echo $lang['href_list'];?></a><br />
						<?php } ?>
						
						<?php
						if (!isset($display)) {
						?>
						<a href="node_register_user.php" class="txt_sub_menu"><?php echo $lang['href_add'];?></a><br />
						<?php } ?>
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">
			<?php
			if (isset($display) && $display == "view_user") {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['section_user'];?><br />
						<hr />
					</td>
				</tr>
			</table>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2">
						<b><?php echo $user['user_firstname'] . " " . $user['user_surname'];?></b><br />
					</td>
				</tr>
				<tr>
					<td width="40%">
						<?php echo $lang['txt_user_id'];?><br />
					</td>
					<td width="60%">
						<?php echo $user['user_id'];?><br />
					</td>
				</tr>
				<tr>
					<td width="40%">
						<?php echo $lang['txt_user_number'];?><br />
					</td>
					<td width="60%">
						<?php echo $user['user_number'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_user_email'];?><br />
					</td>
					<td>
						<a href="mailto:<?php echo $user['user_email'];?>"><?php echo $user['user_email'];?></a><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_hometown'];?><br />
					</td>
					<td>
						<?php echo $user['user_hometown'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_dob'];?><br />
					</td>
					<td>
						<?php echo $user['user_dob'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_gender'];?><br />
					</td>
					<td>
						<?php echo $user['user_gender'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_language'];?><br />
					</td>
					<td>
						<?php echo $lang['arr_lang_name'][$user['language_id']];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_status'];?><br />
					</td>
					<td>
						<?php echo $lang['arr_user_status'][$user['status_id']];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_role'];?><br />
					</td>
					<td>
						<?php echo $lang['arr_acs']['role'][$user['role_id']];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_user_create_datetime'];?><br />
					</td>
					<td>
						<?php echo $user['display_user_create_datetime'];?><br />
					</td>
			    </tr>
				<tr>
					<td>
						<?php echo $lang['txt_file_allocation'];?><br />
					</td>
					<td>
						<?php echo round($user['user_file_allocation']/1000, 2);?>kb<br />
					</td>
			    </tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="25" alt="" /><br />
			
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['section_profile'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top" rowspan="5">
						<img src="get_file.php?file=<?php echo $profile['image']['file'];?>" align="left" border="0" class="picture" alt="<?php echo $profile['image']['file_title'];?>" /><br />
					</td>
					<td>
						<?php echo $lang['txt_profile_name'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_name'];?><br />
					</td>
				</tr>
				
				<tr>
					<td valign="top">
						<?php echo $lang['txt_profile_nic'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_nic'];?><br />
					</td>
				</tr>
				
				<tr>
					<td>
						<?php echo $lang['txt_profile_msn_account'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_msn_account'];?><br />
					</td>
				</tr>
				
				<tr>
					<td>
						<?php echo $lang['txt_profile_yahoo_account'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_yahoo_account'];?><br />
					</td>
				</tr>
				
				<tr>
					<td>
						<?php echo $lang['txt_profile_icq_account'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_icq_account'];?><br />
					</td>
				</tr>
			</table>
			
			<?php
			}
			elseif (isset($display) && $display == "edit_user") {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_user'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<b><?php echo $user['user_firstname'] . " " . $user['user_surname'];?></b><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_user_number'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<input type="text" name="data[user_number]" class="formInput" size="30" value="<?php echo $user['user_number'];?>"><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_file_allocation'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<input type="text" name="data[user_file_allocation]" class="formInput" size="10" value="<?php echo round($user['user_file_allocation']/1000, 2);?>">kb<br />
					</td>
			    </tr>
				<tr>
					<td>
						<?php echo $lang['txt_status'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<select name="data[status_id]" size="1" class="formInput">
						<?php foreach($lang['arr_user_status'] as $key => $i): 
						?>
						<option value="<?php echo $key;?>" <? if($user['status_id'] == $key) echo "selected=\"selected\"";?>><?php echo $i;?></option>
						<?php endforeach; ?>
						</select>
						<br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_role'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<select name="data[role_id]" size="1" class="formInput">
						<?php foreach($lang['arr_acs']['role'] as $key => $i): 
						?>
						<option value="<?php echo $key;?>" <? if($user['role_id'] == $key) echo "selected=\"selected\"";?>><?php echo $i;?></option>
						<?php endforeach; ?>
						</select>
						<br />
					</td>
				</tr>
				<tr>
					<td align="right">
						<input type="submit" name="update_user" value="<?php echo $lang['sub_update_user'];?>" class="formInput"><br />
					</td>
				</tr>
			</table>
			<?php
			}
			else {
			?>
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td class="txt_title" align="right" colspan="5">
						<?php echo $lang['menu_user_list'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						&nbsp;<br />
					</td>
					<td>
						<?php echo $lang['txt_name'];?><br />
					</td>
					<td>
						<?php echo $lang['txt_hometown'];?><br />
					</td>
					<td>
						<?php echo $lang['txt_user_create_datetime'];?><br />
					</td>
				</tr>
				<?php
				if (isset($users[0])) {
				foreach($users as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="node_user.php?user_id=<?php echo $i['user_id'];?>"><?php echo $i['user_id'];?></a><br />
					</td>
					<td valign="top">
						<?php echo $i['user_firstname'] . " " . $i['user_surname'];?><br />
					</td>
					<td valign="top">
						<?php echo $i['user_hometown'];?><br />
					</td>
					<td valign="top">
						<?php echo $i['display_user_create_datetime'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						&nbsp;<br />
					</td>
					<td class="txt_footer" colspan="5">
						<?php
						if (isset($lang['arr_lang_name'][$i['language_id']])) {
						    echo $lang['arr_lang_name'][$i['language_id']];
						}
						?>,
						<?php
						if (isset($lang['arr_user_status'][$i['status_id']])) {
						    echo $lang['arr_user_status'][$i['status_id']];
						}
						?>,
						<?php
						if (isset($lang['arr_acs']['role'][$i['role_id']])) {
						    echo $lang['arr_acs']['role'][$i['role_id']];
						}
						?>
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td colspan="5">
						<?php echo $lang['err_no_users'];?><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>
			<?php
			}
			?>
		</td>
	</tr>
</table>
</form>

==> aroundme_0_4_1.zip: aroundme_0_4_1/www/aroundme_0_4_1/template/am_default/node_user.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="node_user.php" method="post">
<input type="hidden" name="data[user_id]" value="<?php echo $user['user_id'];?>" />

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "node_menu.inc.tpl.php";
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_action'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<?php
						if (isset($display) && $display == "view_user") {
						?>
						<a href="sn_profile.php?user_id=<?php echo $user['user_id'];?>" class="txt_sub_menu"><?php echo $lang['href_go_to_user'];?></a><br />
						<a href="node_user.php?edit_user=1&amp;user_id=<?php echo $user['user_id'];?>" class="txt_sub_menu"><?php echo $lang['href_edit_user'];?></a><br />
						<a href="node_user.php" class="txt_sub_menu"><?php echo $lang['href_list'];?></a><br />
						<?php } ?>
						
						<?php
						if (!isset($display)) {
						?>
						<a href="node_register_user.php" class="txt_sub_menu"><?php echo $lang['href_add'];?></a><br />
						<?php } ?>
					</td>
				</tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="570" valign="top">
			<?php
			if (isset($display) && $display == "view_user") {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2" class="txt_title" align="right">
						<?php echo $lang['section_user'];?><br />
						<hr />
					</td>
				</tr>
			</table>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="2">
						<b><?php echo $user['user_firstname'] . " " . $user['user_surname'];?></b><br />
					</td>
				</tr>
				<tr>
					<td width="40%">
						<?php echo $lang['txt_user_id'];?><br />
					</td>
					<td width="60%">
						<?php echo $user['user_id'];?><br />
					</td>
				</tr>
				<tr>
					<td width="40%">
						<?php echo $lang['txt_user_number'];?><br />
					</td>
					<td width="60%">
						<?php echo $user['user_number'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_user_email'];?><br />
					</td>
					<td>
						<a href="mailto:<?php echo $user['user_email'];?>"><?php echo $user['user_email'];?></a><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_hometown'];?><br />
					</td>
					<td>
						<?php echo $user['user_hometown'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_dob'];?><br />
					</td>
					<td>
						<?php echo $user['user_dob'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_gender'];?><br />
					</td>
					<td>
						<?php echo $user['user_gender'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_language'];?><br />
					</td>
					<td>
						<?php echo $lang['arr_lang_name'][$user['language_id']];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_status'];?><br />
					</td>
					<td>
						<?php echo $lang['arr_user_status'][$user['status_id']];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_role'];?><br />
					</td>
					<td>
						<?php echo $lang['arr_acs']['role'][$user['role_id']];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_user_create_datetime'];?><br />
					</td>
					<td>
						<?php echo $user['display_user_create_datetime'];?><br />
					</td>
			    </tr>
				<tr>
					<td>
						<?php echo $lang['txt_file_allocation'];?><br />
					</td>
					<td>
						<?php echo round($user['user_file_allocation']/1000, 2);?>kb<br />
					</td>
			    </tr>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="25" alt="" /><br />
			
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['section_profile'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td valign="top" rowspan="12">
						<img src="get_file.php?file=<?php echo $profile['image']['file'];?>" align="left" border="0" class="picture" alt="<?php echo $profile['image']['file_title'];?>" /><br />
					</td>
					<td>
						<?php echo $lang['txt_profile_name'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_name'];?><br />
					</td>
				</tr>
				
				<tr>
					<td valign="top">
						<?php echo $lang['txt_profile_nic'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_nic'];?><br />
					</td>
				</tr>
				<?php
				if (!empty($lang['txt_profile_text1'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text1'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text1'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text2'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text2'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text2'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text3'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text3'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text3'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text4'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text4'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text4'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text5'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text5'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text5'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text6'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text6'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text6'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text7'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text7'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text7'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text8'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text8'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text8'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text9'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text9'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text9'];?><br />
					</td>
				</tr>
				<?php }?>
				
				<?php
				if (!empty($lang['txt_profile_text10'])) {
				?>
				<tr>
					<td>
						<?php echo $lang['txt_profile_text10'];?><br />
					</td>
					<td>
						<?php echo $profile['profile_text10'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>
			
			<?php
			}
			elseif (isset($display) && $display == "edit_user") {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_user'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<b><?php echo $user['user_firstname'] . " " . $user['user_surname'];?></b><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_user_number'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<input type="text" name="data[user_number]" class="formInput" size="30" value="<?php echo $user['user_number'];?>"><br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_file_allocation'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<input type="text" name="data[user_file_allocation]" class="formInput" size="10" value="<?php echo round($user['user_file_allocation']/1000, 2);?>">kb<br />
					</td>
			    </tr>
				<tr>
					<td>
						<?php echo $lang['txt_status'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<select name="data[status_id]" size="1" class="formInput">
						<?php foreach($lang['arr_user_status'] as $key => $i): 
						?>
						<option value="<?php echo $key;?>" <? if($user['status_id'] == $key) echo "selected=\"selected\"";?>><?php echo $i;?></option>
						<?php endforeach; ?>
						</select>
						<br />
					</td>
				</tr>
				<tr>
					<td>
						<?php echo $lang['txt_role'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<select name="data[role_id]" size="1" class="formInput">
						<?php foreach($lang['arr_acs']['role'] as $key => $i): 
						?>
						<option value="<?php echo $key;?>" <? if($user['role_id'] == $key) echo "selected=\"selected\"";?>><?php echo $i;?></option>
						<?php endforeach; ?>
						</select>
						<br />
					</td>
				</tr>
				<tr>
					<td align="right">
						<input type="submit" name="update_user" value="<?php echo $lang['sub_update_user'];?>" class="formInput"><br />
					</td>
				</tr>
			</table>
			<?php
			}
			else {
			?>
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr>
					<td class="txt_title" align="right" colspan="5">
						<?php echo $lang['menu_user_list'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						&nbsp;<br />
					</td>
					<td>
						<?php echo $lang['txt_name'];?><br />
					</td>
					<td>
						<?php echo $lang['txt_hometown'];?><br />
					</td>
					<td>
						<?php echo $lang['txt_user_create_datetime'];?><br />
					</td>
				</tr>
				<?php
				if (isset($users)) {
				foreach($users as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="node_user.php?user_id=<?php echo $i['user_id'];?>"><?php echo $i['user_id'];?></a><br />
					</td>
					<td valign="top">
						<?php echo $i['user_firstname'] . " " . $i['user_surname'];?><br />
					</td>
					<td valign="top">
						<?php echo $i['user_hometown'];?><br />
					</td>
					<td valign="top">
						<?php echo $i['display_user_create_datetime'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						&nbsp;<br />
					</td>
					<td class="txt_footer" colspan="5">
						<?php
						if (isset($lang['arr_lang_name'][$i['language_id']])) {
						    echo $lang['arr_lang_name'][$i['language_id']];
						}
						?>,
						<?php
						if (isset($lang['arr_user_status'][$i['status_id']])) {
						    echo $lang['arr_user_status'][$i['status_id']];
						}
						?>,
						<?php
						if (isset($lang['arr_acs']['role'][$i['role_id']])) {
						    echo $lang['arr_acs']['role'][$i['role_id']];
						}
						?>
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td colspan="5">
						<?php echo $lang['err_no_users'];?><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>
			<?php
			}
			?>
		</td>
	</tr>
</table>
</form>
